==> cf-ddns-1.1.0.tar.gz: cf-ddns-1.1.0/setup.py <==
from codecs import open
from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="cf-ddns",
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version="1.1.0",
    description="CloudFlare Dynamic DNS updater",
    long_description=long_description,
    # The project's main homepage.
    url="https://github.com/maedox/cf-ddns",
    # Author details
    author="Pål Nilsen",
    author_email="paal.nilsen@gmail.com",
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Site Management",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    keywords="ddns cloudflare",
    install_requires=["requests"],
    extras_require={"sentry": ["raven"]},
    scripts=["cf-ddns"],
)

==> cf-ddns-1.1.1.tar.gz: cf-ddns-1.1.1/setup.py <==
from codecs import open
from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="cf-ddns",
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version="1.1.1",
    description="CloudFlare Dynamic DNS updater",
    long_description=long_description,
    # The project's main homepage.
    url="https://github.com/maedox/cf-ddns",
    # Author details
    author="Pål Nilsen",
    author_email="paal.nilsen@gmail.com",
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Site Management",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    keywords="ddns cloudflare",
    install_requires=["requests", "urllib3"],
    extras_require={"sentry": ["raven"]},
    scripts=["cf-ddns"],
)
